@@ -9,6 +9,8 @@ from jupyter_process_manager.class_processes_manager import \
 from . import logger
 from .function_wrapper import clear_output
 from .function_wrapper import read_stdout
+from .function_wrapper import check_if_output_redirected
+from .function_wrapper import redirect_outputs_for_main
 
 
 JupyterProcessManager = JupyterProcessesManager
@@ -18,6 +20,7 @@ JPM = JupyterProcessesManager
 __all__ = [
     "JupyterProcessesManager", "JupyterProcessManager", "JPM",
     "clear_output", "read_stdout",
+    "check_if_output_redirected", "redirect_outputs_for_main",
 ]
 
 # Create LOGGER for current project
